/*!
 *****************************************************************************
 * @file:   ADuCM410_Setup.c
 * @brief:  setup for ADuCM410
 *-----------------------------------------------------------------------------
 *
Copyright (c) 2013-2018 Analog Devices, Inc. All Rights Reserved.

This software is proprietary to Analog Devices, Inc. and its licensors.
By using this software you agree to the terms of the associated
Analog Devices Software License Agreement.
 ******************************************************************************/

#include "SpiLib.h"
#include "ClkLib.h"

/*
   User can change following cofiguraion according to application
*/
CLK_SETUP_t gClkSetup = 
{
   //--------- configuration ---------
	.pllEn = 1,
   .rootClkMux = ENUM_CLOCK_CLKCON0_CLKMUX_SPLL,
   .analogClkMux = ENUM_CLOCK_CLKCON0_ANACLKMUX_HFOSC,
    

//-----------------Clock Divider -------------   
   .hclkDiv = ENUM_CLOCK_CLKCON1_CDHCLK_DIV1,
   .pclk0Div = ENUM_CLOCK_CLKCON1_CDPCLK0_DIV8,
   .pclk1Div = ENUM_CLOCK_CLKCON1_CDPCLK1_DIV1,
    
   .clockOff = 0x00000000,  //all clock on

   //---------Interrupt------------
   .pllIntEn = 0,    //0 - disalbe interrrupt related to PLL

   //-------TEST CLOCK -------
   .clkOutput = ENUM_CLOCK_CLKCON0_CLKOUT_B1_PCLK,
};

SPI_SETUP_t gSpi0Setup = 
{
   .spiEn = 1,
   .masterEn = 1,
   .cpha = 1,   //clock pahse
   .cpol = 0,      //clock polarity 
   .wireOrEn = 0,//0 - SPI wire or mode disabled
   .lsbFirst = 0,   //0 - MSB transfered first
   .txTrigTransfer = 1, //0 - initiate transfer when read Rx reigster.
   .rxOverwrite = 1,//1 - Rx resigter is overwriten by new serial byte received
   .fifoEmtpyTx = FIFOEMPTY_TX_0,   //1 - send '0' when no valid data in Tx FIFO
   .misoEn = 0,  //1 - enable miso drive in slave mode
   .continousTx = 1,   //1 - transfer continous until no valid data in Tx register.
   .loopback = 0,   //1 - enable loopback
   .threePinMode = 0,  //0 - normal mode

   //----------- Interrupt -------------
   .txrxIrqByte = ENUM_SPI_IEN_IRQMODE_TX1RX1,//Interrupt Occurs After 4 Byte is Transfered or Received
   .csIntEn = 0,
   .txUnderflowIntEn = 0,
   .rxOverflowIntEn = 0,
   .readyIntEn = 0,
   .txDoneIntEn = 0,
   .frameEndIntEn = 0,
   .txFifoEmptyIntEn = 0,

   //------------- Dma -----------------
   .txDmaEn = 0,
   .rxDmaEn = 0,

   //-------------- Read command mode -----------
   .readCmdEn = 0, //0 - disable read command mode
   .txByte = 0,    //number of bytes to be transmitted before reading data
   .txRxOverlap = 0,
};

SPI_SETUP_t gSpi1Setup = 
{
   .spiEn = 1,
   .masterEn = 1,
   .cpha = 1,   //clock pahse
   .cpol = 1,      //clock polarity 
   .wireOrEn = 0,//0 - SPI wire or mode disabled
   .lsbFirst = 0,   //0 - MSB transfered first
   .txTrigTransfer = 1, 
   .rxOverwrite = 1,//1 - Rx resigter is overwriten by new serial byte received
   .fifoEmtpyTx = FIFOEMPTY_TX_0,   //1 - send '0' when no valid data in Tx FIFO
   .misoEn = 0,  //1 - enable miso drive in slave mode
   .continousTx = 1,   //1 - transfer continous until no valid data in Tx register.
   .loopback = 0,   //1 - enable loopback
   .threePinMode = 0,  //0 - normal mode

   //----------- Interrupt -------------
   .txrxIrqByte = 0,//Interrupt Occurs After 4 Byte is Transfered or Received
   .csIntEn = 0,
   .txUnderflowIntEn = 0,
   .rxOverflowIntEn = 0,
   .readyIntEn = 0,
   .txDoneIntEn = 0,
   .frameEndIntEn = 0,
   .txFifoEmptyIntEn = 0,

   //------------- Dma -----------------
   .txDmaEn = 0,
   .rxDmaEn = 0,

   //-------------- Read command mode -----------
   .readCmdEn = 0, //0 - disable read command mode
   .txByte = 0,    //number of bytes to be transmitted before reading data
   .txRxOverlap = 0,
};


