/*!
 *****************************************************************************
 * @file:
 * @brief:
 *-----------------------------------------------------------------------------
 *
Copyright (c) 2013-2018 Analog Devices, Inc. All Rights Reserved.

This software is proprietary to Analog Devices, Inc. and its licensors.
By using this software you agree to the terms of the associated
Analog Devices Software License Agreement.
 ******************************************************************************/

#include "ADuCM410.h"
#include "WdtLib.h"
#include "common.h"
#include "DioLib.h"
#include "ClkLib.h"
#include "SpiLib.h"

#define SPI_TX_BUFFER_LEN  8
#define SPI_RX_BUFFER_LEN  8

//Variables declaration
extern uint8_t SpiTxBuf[SPI_TX_BUFFER_LEN];
extern uint32_t txCnt;
extern uint8_t SpiRxBuf[SPI_RX_BUFFER_LEN];
extern uint8_t *pSpiRxBuf;
extern volatile uint32_t rxCnt;

// Function declaration
void SafetyWait(void);
void delay(uint32_t t);
void Spi0LoopbackTest(void);
void Spi1TxTest(void);
void Spi1RxTest(void);


uint8_t SpiTxBuf[SPI_TX_BUFFER_LEN] = {'A','D','u','C','M','4','1','0'};
uint32_t txCnt = 0;
uint8_t SpiRxBuf[SPI_RX_BUFFER_LEN] = {0};
uint8_t *pSpiRxBuf =  SpiRxBuf;
volatile uint32_t rxCnt = 0;

void Spi0LoopbackTest()
{
	uint32_t i;
   //GPIO setup
   DioCfgPin(pADI_GPIO0,PIN0,P0_0_SPI0_SCLK);
   //DioPulPin(pADI_GPIO0,PIN0,1);
   DioCfgPin(pADI_GPIO0,PIN1,P0_1_SPI0_MISO);
   DioCfgPin(pADI_GPIO0,PIN2,P0_2_SPI0_MOSI);
   DioCfgPin(pADI_GPIO0,PIN3,P0_3_SPI0_CS);
   
   //SPI setup
   SpiSetup(pADI_SPI0,&gSpi0Setup);
   //set SPI clock
	//160MHz/(2*(1+div))
   SpiBaud(pADI_SPI0,9);   //8MHz
   
   pADI_SPI0->CNT = 9;   //send 9 bytes
	
	for(i=0;i<8;i++)
	{
		SpiTx(pADI_SPI0,i);	//write  bytes to prepare transfer in loop back mode
	}
	SpiRx(pADI_SPI0);	//read to tigger transfer
	NVIC_EnableIRQ(SPI0_IRQn);
   
}

void Spi1TxTest()
{
   //GPIO setup
   DioCfgPin(pADI_GPIO1,PIN4,P1_4_SPI1_SCLK);
   DioCfgPin(pADI_GPIO1,PIN5,P1_5_SPI1_MISO);
   DioCfgPin(pADI_GPIO1,PIN6,P1_6_SPI1_MOSI);
   DioCfgPin(pADI_GPIO1,PIN7,P1_7_SPI1_CS);
   DioPulPin(pADI_GPIO1,PIN4,1);
   DioPulPin(pADI_GPIO1,PIN5,1);
   DioPulPin(pADI_GPIO1,PIN6,1);
   DioPulPin(pADI_GPIO1,PIN7,1);
   
   //SPI setup
   SpiSetup(pADI_SPI1,&gSpi1Setup);
   //set SPI clock
	//160MHz/(2*(1+div))
   SpiBaud(pADI_SPI1,19);   //4MHz
   
   pADI_SPI1->CNT = SPI_TX_BUFFER_LEN;   //send 8 bytes
   SpiTx(pADI_SPI1,SpiTxBuf[txCnt++]);//write  bytes start transfer
	
	NVIC_EnableIRQ(SPI1_IRQn);  
}

void Spi1RxTest()
{
   //GPIO setup
   DioCfgPin(pADI_GPIO1,PIN4,P1_4_SPI1_SCLK);
   DioCfgPin(pADI_GPIO1,PIN5,P1_5_SPI1_MISO);
   DioCfgPin(pADI_GPIO1,PIN6,P1_6_SPI1_MOSI);
   DioCfgPin(pADI_GPIO1,PIN7,P1_7_SPI1_CS);
   DioOenPin(pADI_GPIO1,PIN6,1);
   DioOenPin(pADI_GPIO1,PIN7,1);
   DioOenPin(pADI_GPIO1,PIN4,1);
   DioIenPin(pADI_GPIO1,PIN5,1);
   pADI_GPIO1->PE |= 0xF0;
   
   //SPI setup
   gSpi1Setup.txTrigTransfer = 1;   //read to transfer
   SpiSetup(pADI_SPI1,&gSpi1Setup);
   //set SPI clock
	//160MHz/(2*(1+div))
   SpiBaud(pADI_SPI1,79);   //1MHz
   
   //pADI_SPI1->CNT = SPI_RX_BUFFER_LEN;   //send 8 bytes
   pADI_SPI1->CNT = 2;
   

   pADI_SPI1->CNT = 3;
   pADI_SPI1->TX = 0xFF >> 16;
   pADI_SPI1->TX = 0xFF >> 8;
   pADI_SPI1->TX = 0xFF & 0xFF;
   //while((pSPI_AFE->FIFO_STAT & (0x000F<<8)) < 3){}
   //while((pSPI_AFE->FIFO_STAT & (0x000F<<0)) != 0){}
   while(!(pADI_SPI1->STAT &(1<<1)));//WAIt xfrdone
   pADI_SPI1->STAT = 0xff;
   SpiRxBuf[txCnt++] = (uint8_t)(pADI_SPI1->RX);
   SpiRxBuf[txCnt++] = (uint8_t)(pADI_SPI1->RX);
   SpiRxBuf[txCnt++] = (uint8_t)(pADI_SPI1->RX&0xFF);

   
   //SpiRx(pADI_SPI1);
	
	//NVIC_EnableIRQ(SPI1_IRQn);  
}

int main (void)
{
  pSpiRxBuf =  SpiRxBuf;
  rxCnt = 0;
  txCnt = 0;
    WdtGo(false);

    ClkSetup(&gClkSetup);

    SystemInit();
    INIT();
    SafetyWait();
    
    //Spi0LoopbackTest();
    
    delay(10000);
    //Spi1TxTest();
    Spi1RxTest();

	 //while(rxCnt<5);
	 delay(500);
    
    for(uint32_t i=0;i<rxCnt;i++)
    {
      DEBUG_MESSAGE("%d,%d",i,SpiRxBuf[i]);
    }


    while(1)
    {
        delay(10000);
        //WdtRefresh();
    }

}

void delay(uint32_t t)
{
   uint32_t i;
   for(i=0;i<t;i++);
}

void SPI0_Int_Handler()
{
   uint32_t sta,rxFifoSta;
   sta = pADI_SPI0->STAT;	
   if(sta&BITM_SPI_STAT_RXIRQ)  //TIM set to 0, rx IRQ when received data
   {
		rxFifoSta = pADI_SPI0->FIFOSTAT>>BITP_SPI_FIFOSTAT_RX;
	  while(rxFifoSta)
	  {
	   rxFifoSta--;
    	*pSpiRxBuf++ = (uint8_t)(pADI_SPI0->RX);
		rxCnt++;
	  }
   }
   pADI_SPI0->STAT = (uint16_t)sta;  //clear status
   //DEBUG_PIN0_TOGGLE();
}

void SPI1_Int_Handler()
{
   uint32_t sta,rxFifoSta;
   sta = pADI_SPI1->STAT;	
   if(sta&BITM_SPI_STAT_RXIRQ)  //TIM set to 0, rx IRQ when received data
   {
		rxFifoSta = pADI_SPI1->FIFOSTAT>>BITP_SPI_FIFOSTAT_RX;
	  while(rxFifoSta)
	  {
	   rxFifoSta--;
    	*pSpiRxBuf++ = (uint8_t)(pADI_SPI1->RX);
		rxCnt++;
	  }
   }
   if(sta&BITM_SPI_STAT_TXIRQ)
   {
      SpiTx(pADI_SPI1,SpiTxBuf[txCnt]);
      txCnt++;
   }
   pADI_SPI1->STAT = (uint16_t)sta;  //clear status
   //DEBUG_PIN0_TOGGLE();
}




